# sugar-lint: disable

from __init__ import tests

from collector import *

tests.main()
